DynamicMemory

Struct DynamicMemory 

pub struct DynamicMemory { /* private fields */ }
This is an internal-only api.

A Dynamic memory allocates only the minimum amount of memory when first created. Over time, as it grows, it may reallocate to a different location and size.

Dynamic memories are significantly faster to create than static memories and use much less virtual memory, however, they require the WebAssembly module to bounds-check memory accesses.

While, a dynamic memory could use a vector of some sort as its backing memory, we use mmap (or the platform-equivalent) to allow us to add a guard-page at the end to help elide some bounds-checks.

Implementations

Source

impl DynamicMemory

pub fn size(&self) -> Pages

The size of this memory in Pages.

pub fn grow( &mut self, delta: Pages, local: &mut LocalMemory, ) -> Result<Pages, GrowError>

Try to grow self by the given number of delta pages.

pub fn as_slice(&self) -> &[u8]

Get this memory represented as a slice of bytes.

pub fn as_slice_mut(&mut self) -> &mut [u8]

Get this memory represented as a mutable slice of bytes