StaticMemory

Struct StaticMemory 

pub struct StaticMemory { /* private fields */ }
This is an internal-only api.

A static memory allocates 6GB of virtual memory when created in order to allow the WebAssembly module to contain no bounds-checks.

Additionally, static memories stay at a single virtual address, so there is no need to reload its address on each use.

Static memories take a relatively long time to create, so if memories are short-lived, it’s recommended that a dynamic memory is used. There is currently no user-facing api that allows them to select the type of memory used however.

Implementations

Source

impl StaticMemory

pub fn size(&self) -> Pages

The size of this memory in Pages.

pub fn grow( &mut self, delta: Pages, local: &mut LocalMemory, ) -> Result<Pages, GrowError>

Try to grow this memory by the given number of delta pages.

pub fn as_slice(&self) -> &[u8]

Get this memory represented as a slice of bytes.

pub fn as_slice_mut(&mut self) -> &mut [u8]

Get this memory represented as a mutable slice of bytes.