LocalBacking

Struct LocalBacking 

pub struct LocalBacking { /* private fields */ }
The LocalBacking “owns” the memory used by all the local resources of an Instance. That is, local memories, tables, and globals (as well as some additional data for the virtual call machinery).